@@ -22,11 +22,12 @@ from decimal import Decimal
 
 import django.db.models as dm
 from django.db import IntegrityError
+from django.conf import settings as django_settings
 from django.core.exceptions import ValidationError
 
 import hypothesis.strategies as st
 from hypothesis.errors import InvalidArgument
-from hypothesis.extra.datetime import datetimes
+from hypothesis.extra.pytz import timezones
 from hypothesis.utils.conventions import UniqueIdentifier
 from hypothesis.searchstrategy.strategies import SearchStrategy
 
@@ -47,6 +48,12 @@ def referenced_models(model, seen=None):
     return seen
 
 
+def get_datetime_strat():
+    if getattr(django_settings, 'USE_TZ', False):
+        return st.datetimes(timezones=timezones())
+    return st.datetimes()
+
+
 __default_field_mappings = None
 
 
@@ -63,7 +70,7 @@ def field_mappings():
             dm.PositiveSmallIntegerField: st.integers(0, 32767),
             dm.BinaryField: st.binary(),
             dm.BooleanField: st.booleans(),
-            dm.DateTimeField: datetimes(allow_naive=False),
+            dm.DateTimeField: get_datetime_strat(),
             dm.FloatField: st.floats(),
             dm.NullBooleanField: st.one_of(st.none(), st.booleans()),
         }
